import { useSupabaseUser } from "../composables/useSupabaseUser.mjs";
import { useSupabaseClient } from "../composables/useSupabaseClient.mjs";
import { useSupabaseToken } from "../composables/useSupabaseToken.mjs";
import { defineNuxtPlugin, useRuntimeConfig } from "#imports";
export default defineNuxtPlugin(async () => {
  const user = useSupabaseUser();
  const client = useSupabaseClient();
  const token = useSupabaseToken();
  if (!token.value) {
    user.value = null;
    return redirectToLogin();
  }
  const { data: { user: supabaseUser }, error } = await client.auth.getUser(token.value);
  if (error) {
    token.value = null;
    user.value = null;
    return redirectToLogin();
  } else {
    user.value = supabaseUser;
  }
});
const redirectToLogin = async () => {
  const redirect = useRuntimeConfig().public.supabase.redirect;
  if (redirect && redirect.login) {
    const route = useRoute();
    if ([redirect.login, redirect.callback].includes(route.path)) {
      return;
    }
    await navigateTo(redirect.login);
  }
};
